Learn R Programming

NAVAECI (version 0.1.1)

.computeTuningParameters_OLS: Compute tuning parameters for the NAVAE confidence interval in the linear regression case

Description

Compute tuning parameters for the NAVAE confidence interval in the linear regression case

Usage

.computeTuningParameters_OLS(n, a = NULL, omega = NULL)

# S3 method for NAVAE_CI_OLS_TuningParameters print(x, ...)

Value

.computeTuningParameters_OLS returns an object of class NAVAE_CI_OLS_TuningParameters with the values of the tuning parameters and some information on how they were determined.

print displays information about the tuning parameters and returns x invisibly.

Arguments

n

sample size

a

parameter a in the function Navae_ci_ols

omega

parameter omega in the function Navae_ci_ols

x

object to be printed

...

other arguments to passed to print, currently unused.

Examples

Run this code

.computeTuningParameters_OLS(n = 1000)
.computeTuningParameters_OLS(n = 1000, a = 2)
.computeTuningParameters_OLS(n = 1000, a = list(power_of_n_for_b = -1/3))
.computeTuningParameters_OLS(n = 1000, omega = 0.2)
.computeTuningParameters_OLS(n = 1000, omega = list(power_of_n_for_omega = -0.2))

Run the code above in your browser using DataLab