Learn R Programming

NAVAECI (version 0.1.1)

print.NAVAE_CI_Mean: Print and coerce a NAVAE_CI_Mean object

Description

Print and coerce a NAVAE_CI_Mean object

Usage

# S3 method for NAVAE_CI_Mean
print(x, verbose = 0, ...)

# S3 method for NAVAE_CI_Mean as.data.frame(x, ...)

Value

print.Navae_ci_ols prints information about x and returns it invisibly.

as.data.frame returns a data.frame with 2 rows.

Arguments

x

the object

verbose

if zero, only basic printing is done. Higher values corresponds to more detailed output.

...

other arguments, currently ignored.

References

Derumigny, A., Girard, L., & Guyonvarch, Y. (2025). Can we have it all? Non-asymptotically valid and asymptotically exact confidence intervals for expectations and linear regressions. ArXiv preprint, tools:::Rd_expr_doi("10.48550/arXiv.2507.16776")

See Also

The function to generate such objects Navae_ci_mean.

The corresponding methods for the regression (OLS): print.NAVAE_CI_OLS and as.data.frame.NAVAE_CI_OLS.

Examples

Run this code
n = 10000
x = rexp(n, 1)
myCI = Navae_ci_mean(x, bound_K = 9, alpha = 0.2)

print(myCI)
as.data.frame(myCI)


Run the code above in your browser using DataLab